@@ -69,22 +69,23 @@ class BaseErrCorrForm(abc.ABC):
         """Form name"""
         pass
 
-    def expand_dim_matrix(
-        self, submatrix: np.ndarray, submatrix_dim: Union[str, List[str]], sli: tuple
-    ):
-        return expand_errcorr_dims(
-            in_corr=submatrix,
-            in_dim=submatrix_dim,
-            out_dim=list(self._obj[self._unc_var_name][sli].dims),
-            dim_sizes=self.get_sliced_dim_sizes_uncvar(sli),
-        )
+    def get_varshape_errcorr(self):
+        """
+        return shape of uncertainty variable, including only dimensions which are included in the current error correlation form.
+
+        :return: shape of included dimensions
+        """
+        all_dims = self._obj[self._unc_var_name].dims
+        all_dims_sizes = self._obj.sizes
+
+        return tuple([all_dims_sizes[dim] for dim in all_dims if dim in self.dims])
 
     def get_sliced_dim_sizes_uncvar(self, sli: tuple) -> dict:
         """
         Return dictionary with sizes of sliced dimensions of unc variable, including all dimensions.
 
         :param sli: slice (tuple with slice for each dimension)
-        :return: shape of included sliced dimensions
+        :return: dictionary with shape of included sliced dimensions
         """
         uncvar_dims = self._obj[self._unc_var_name][sli].dims
         uncvar_shape = self._obj[self._unc_var_name][sli].shape
@@ -98,7 +99,7 @@ class BaseErrCorrForm(abc.ABC):
         included in the current error correlation form.
 
         :param sli: slice (tuple with slice for each dimension)
-        :return: shape of included sliced dimensions
+        :return: dictionary with shape of included sliced dimensions
         """
         uncvar_sizes = self.get_sliced_dim_sizes_uncvar(sli)
         sliced_dims = self.get_sliced_dims_errcorr(sli)
@@ -131,17 +132,21 @@ class BaseErrCorrForm(abc.ABC):
 
         return tuple([uncvar_sizes[dim] for dim in sliced_dims])
 
-    def slice_full_cov(self, full_matrix: np.ndarray, sli: tuple) -> np.ndarray:
-        return self.slice_flattened_matrix(
-            full_matrix, self._obj[self._unc_var_name].shape, sli
-        )
+    def slice_errcorr_matrix(self, err_corr_matrix, variable_shape, sli) -> np.ndarray:
+        """
+        Slice the provided error correlation matrix (typically the error correlation matrix of the
+        BaseErrCorrForm) using the
 
-    def slice_flattened_matrix(self, flattened_matrix, variable_shape, sli):
+        :param err_corr_matrix: error correlation matrix to be sliced
+        :param variable_shape: tuple with the length of the dimensions in the error correlation matrix (in correct order for flattening)
+        :param sli: slice of observation variable to return error-correlation matrix for
+        :return: sliced error correlation matrix
+        """
         mask_array = np.ones(variable_shape, dtype=bool)
         mask_array[sli] = False
 
         return np.delete(
-            np.delete(flattened_matrix, mask_array.ravel(), 0), mask_array.ravel(), 1
+            np.delete(err_corr_matrix, mask_array.ravel(), 0), mask_array.ravel(), 1
         )
 
     @abc.abstractmethod
@@ -158,16 +163,24 @@ class BaseErrCorrForm(abc.ABC):
 
     def build_dot_matrix(self, sli: Union[np.ndarray, tuple]) -> np.ndarray:
         """
-        Returns uncertainty effect error-correlation matrix, populated with error-correlation values defined
-        in this parameterisation
+        Returns expanded error correlation matrix for use in dot product with error correlation
+        in other dimensions.
+
+        The (sliced) error correlation matrix for this BaseErrCorrForm is expanded from its current
+        (sliced) dimensions (which often don't include all dimensions of the associated uncertainty
+        variable) to the dimensions of the full (sliced) error correlation (i.e. all dimensions of
+        the uncertainty).
+        The returned matrix is not meaningfull unless combined in a dot product with the expanded
+        matrices of other error correlation matrices (together spanning all uncertainty dimensions).
 
         :param sli: slice of observation variable to return error-correlation matrix for
-
-        :return: populated error-correlation matrix
+        :return: expanded matrix for use in dot product with error correlation in other dimensions.
         """
-
-        return self.expand_dim_matrix(
-            self.build_matrix(sli), self.get_sliced_dims_errcorr(sli), sli
+        return expand_errcorr_dims(
+            in_corr=self.build_matrix(sli),
+            in_dim=self.get_sliced_dims_errcorr(sli),
+            out_dim=list(self._obj[self._unc_var_name][sli].dims),
+            dim_sizes=self.get_sliced_dim_sizes_uncvar(sli),
         )
 
 
@@ -250,24 +263,14 @@ class ErrCorrMatrixCorrelation(BaseErrCorrForm):
 
         :return: populated error-correlation matrix
         """
-
         all_dims = self._obj[self._unc_var_name].dims
-        all_dims_sizes = self._obj.sizes
 
         sli_submatrix = tuple(
             [sli[i] for i in range(len(all_dims)) if all_dims[i] in self.dims]
         )
 
-        sliced_shape = tuple(
-            [
-                all_dims_sizes[all_dims[i]]
-                for i in range(len(all_dims))
-                if all_dims[i] in self.dims
-            ]
-        )
-
-        submatrix = self.slice_flattened_matrix(
-            self._obj[self.params[0]], sliced_shape, sli_submatrix
+        submatrix = self.slice_errcorr_matrix(
+            self._obj[self.params[0]], self.get_varshape_errcorr(), sli_submatrix
         )
 
         return submatrix
