@@ -98,7 +98,7 @@ def create_ds():
             "units": "K",
             "err_corr": [
                 {
-                    "dim": "x",
+                    "dim": ["x", "time"],
                     "form": "err_corr_matrix",
                     "params": ["err_corr_str_temperature"],
                 },
@@ -107,19 +107,19 @@ def create_ds():
                     "form": "systematic",
                     "params": [],
                 },
-                {
-                    "dim": "time",
-                    "form": "systematic",
-                    "params": [],
-                },
             ],
             "pdf_shape": "gaussian",
         },
     )
 
     ds["err_corr_str_temperature"] = (
-        ["x", "x"],
-        np.eye(temperature.shape[0]),
+        ["x.time", "x.time"],
+        np.ones(
+            (
+                temperature.shape[0] * temperature.shape[2],
+                temperature.shape[0] * temperature.shape[2],
+            )
+        ),
     )
 
     return ds
